@@ -106,6 +106,22 @@ static void clearStructs(void)
 
 int main(int argc, char *argv[])
 {
+#ifdef _WIN32 // test for SSE/SSE2 presence very first, to make sure no SSE/SSE2 code is attempted to be ran
+	if (!SDL_HasSSE())
+	{
+		MessageBoxA(NULL, "Your computer's processor doesn't have the SSE instruction set " \
+			"which is needed for this program to run. Sorry!", "Error", MB_ICONEXCLAMATION);
+		return 0;
+	}
+
+	if (!SDL_HasSSE2())
+	{
+		MessageBoxA(NULL, "Your computer's processor doesn't have the SSE2 instruction set " \
+			"which is needed for this program to run. Sorry!", "Error", MB_ICONEXCLAMATION);
+		return 0;
+	}
+#endif
+
 #ifndef _WIN32
 	struct sigaction act, oldAct;
 #endif
@@ -173,25 +189,13 @@ int main(int argc, char *argv[])
 	SDL_SetHint("SDL_WINDOWS_NO_CLOSE_ON_ALT_F4", "1");
 #endif
 
+	SDL_SetHint("SDL_MOUSE_FOCUS_CLICKTHROUGH", "1");
+
 #ifdef _WIN32
 #ifndef _MSC_VER
 	SetProcessDPIAware();
 #endif
 
-	if (!SDL_HasSSE())
-	{
-		showErrorMsgBox("Your computer's processor doesn't have the SSE instruction set\n" \
-		                "which is needed for this program to run. Sorry!");
-		return 0;
-	}
-
-	if (!SDL_HasSSE2())
-	{
-		showErrorMsgBox("Your computer's processor doesn't have the SSE2 instruction set\n" \
-		                "which is needed for this program to run. Sorry!");
-		return 0;
-	}
-
 	disableWasapi(); // disable problematic WASAPI SDL2 audio driver on Windows (causes clicks/pops sometimes...)
 	                 // 13.03.2020: This is still needed with SDL 2.0.12...
 #endif
@@ -271,7 +275,7 @@ int main(int argc, char *argv[])
 	hpc_Init();
 	hpc_SetDurationInHz(&video.vblankHpc, VBLANK_HZ);
 
-	if (!initSincWindow() || !setupAudio() || !unpackBMPs())
+	if (!calculateSincKernel() || !setupAudio() || !unpackBMPs())
 	{
 		cleanUp();
 		SDL_Quit();
@@ -376,6 +380,8 @@ int main(int argc, char *argv[])
 
 static void handleInput(void)
 {
+	bool focusGained = false;
+
 	SDL_Event event;
 	while (SDL_PollEvent(&event))
 	{
@@ -386,6 +392,9 @@ static void handleInput(void)
 			else if (event.window.event == SDL_WINDOWEVENT_SHOWN)
 				video.windowHidden = false;
 
+			if (event.window.event == SDL_WINDOWEVENT_FOCUS_GAINED)
+				focusGained = true;
+
 			// reset vblank end time if we minimize window
 			if (event.window.event == SDL_WINDOWEVENT_MINIMIZED || event.window.event == SDL_WINDOWEVENT_FOCUS_LOST)
 				hpc_ResetCounters(&video.vblankHpc);
@@ -465,8 +474,16 @@ static void handleInput(void)
 		}
 		else if (event.type == SDL_MOUSEBUTTONDOWN)
 		{
-			if (ui.sampleMarkingPos == -1 && !ui.forceSampleDrag && !ui.forceVolDrag && !ui.forceSampleEdit)
-				mouseButtonDownHandler(event.button.button);
+			/* If program was not in focus and we clicked somewhere,
+			** only accept the click if an ask box dialog is shown.
+			*/
+			if (!focusGained || ui.askBoxShown)
+			{
+				if (ui.sampleMarkingPos == -1 && !ui.forceSampleDrag && !ui.forceVolDrag && !ui.forceSampleEdit)
+					mouseButtonDownHandler(event.button.button);
+			}
+
+			focusGained = false;
 		}
 #if defined __APPLE__ && defined __aarch64__
 		else if (event.type == SDL_MOUSEMOTION)
